@@ -31,8 +31,16 @@ class LocalBrowsers():
         """Get webdriver for chrome."""
         options = webdriver.ChromeOptions()
         options.add_experimental_option('excludeSwitches', ['enable-logging'])
-        local_driver = webdriver.Chrome(service=ChromeService(ChromeDriverManager().install()),options=options)
-        # local_driver = webdriver.Chrome('./chromedriver/v92/chromedriver')
+        local_driver = webdriver.Chrome()
+        return local_driver
+
+    @staticmethod
+    def wdm_chrome():
+        """Get webdriver for chrome."""
+        options = webdriver.ChromeOptions()
+        desired_version = "113.0.5672.24"
+        options.add_experimental_option('excludeSwitches', ['enable-logging'])
+        local_driver = webdriver.Chrome(service=ChromeService(ChromeDriverManager(version=desired_version).install()), options=options)
         return local_driver
 
     @staticmethod
@@ -82,6 +90,25 @@ class LocalBrowsers():
         options.add_argument('--disable-dev-shm-usage')
         options.add_argument('--no-sandbox')
         options.add_argument('--ignore-certificate-errors')
-        local_driver = webdriver.Chrome(service=ChromeService(ChromeDriverManager().install()),options=options)
+        local_driver = webdriver.Chrome()
+        return local_driver
+
+    @staticmethod
+    def wdm_headless_chrome():
+        """Set up headless chrome driver options and get webdriver for headless chrome."""
+        options = Options()
+        options.headless = True
+        options.add_argument("--window-size=1920,1080")
+        options.add_argument("--disable-extensions")
+        options.add_argument("--proxy-server='direct://'")
+        options.add_argument("--proxy-bypass-list=*")
+        options.add_argument("--start-maximized")
+        options.add_argument('--headless')
+        options.add_argument('--disable-gpu')
+        options.add_argument('--disable-dev-shm-usage')
+        options.add_argument('--no-sandbox')
+        options.add_argument('--ignore-certificate-errors')
+        desired_version = "112.0.5615.121"
+        local_driver = webdriver.Chrome(service=ChromeService(ChromeDriverManager(version=desired_version).install()), options=options)
 
         return local_driver
